Learn R Programming

i18n (version 0.2.0)

cldr_characters: Get localized values from the characters dataset

Description

The characters table contains information on the usage of characters and exemplar character sets across 574 locales. The cldr_characters() function allows one to extract element values from the table by supplying the locale and one of the following element names:

  • "exemplar_characters"

  • "auxiliary"

  • "index"

  • "numbers"

  • "punctuation"

  • "more_info"

  • "ellipsis"

  • "leninent_scope_general"

  • "leninent_scope_date"

  • "leninent_scope_number"

  • "stricter_scope_number"

Usage

cldr_characters(
  locale = "en",
  element = characters_elements$exemplar_characters
)

Value

Either a named list or a length one character vector, depending on the element value.

Arguments

locale

The locale ID for which to obtain the data from the characters table.

element

The element from which information will be obtained for the specified locale.