The locale_names table contains information on how to express components of
locale codes and this is localized across 574 locales.
The cldr_locale_names() function allows one to extract a named list using
a locale and one of the following element names:
"langs": corresponds to the lang_names column in locale_names
"scripts": is the script_names column in locale_names
"territories": is territory_names
"variants": is variant_names
cldr_locale_names(locale = "en", element = locale_names_elements$lang_names)A named list.
The locale ID for which to obtain the data from the locale_names table.
The element from which information will be obtained for the
specified locale. A valid set of locale_names elements can be accessed
through the locale_names_elements list object.