Learn R Programming

i18n (version 0.2.0)

locale_names: A table with localized language, script, and territory names

Description

The locale_names table contains localized names for languages, script names, names for territories, and names for variants. There are 574 rows and the following 5 columns:

  • locale (character)

  • lang_names (named list [variable length])

  • script_names (named list [variable length])

  • territory_names (named list [variable length])

  • variant_names (named list [variable length])

The lang_names column contains named lists for all localized language names. The script_names column holds named lists for all localized script names, and territory_names has all of the localized territory names per locale. The variant_names list column containing named lists for all localized variant names.

Usage

locale_names

Arguments

Format

An object of class tbl_df (inherits from tbl, data.frame) with 574 rows and 5 columns.