The character_labels table contains information on character patterns
and character labels across 574 locales. The
cldr_character_labels() function allows one to extract element values from
the table by supplying the locale and one of the following element names:
"patterns": corresponds to the character_label_patterns column in
character_labels
"labels": is the character_labels column in character_labels
cldr_character_labels(locale = "en", element = c("patterns", "labels"))A named list.
The locale ID for which to obtain the data from the
character_labels table.
The element from which information will be obtained for the
specified locale.