The characters table contains information on the usage of characters
and exemplar character sets across 574 locales. The
cldr_characters() function allows one to extract element values from the
table by supplying the locale and one of the following element names:
"exemplar_characters"
"auxiliary"
"index"
"numbers"
"punctuation"
"more_info"
"ellipsis"
"leninent_scope_general"
"leninent_scope_date"
"leninent_scope_number"
"stricter_scope_number"
cldr_characters(
locale = "en",
element = characters_elements$exemplar_characters
)Either a named list or a length one character vector, depending on
the element value.
The locale ID for which to obtain the data from the characters table.
The element from which information will be obtained for the
specified locale.